@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.0500';
+our $VERSION = '0.0501';
 
 use Moo;
 use strictures 2;
@@ -124,7 +124,7 @@ Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.0500
+version 0.0501
 
 =head1 SYNOPSIS
 
@@ -140,6 +140,7 @@ version 0.0500
   $roman = $mtr->parse('Em7');   # v7 (minor seventh)
   $roman = $mtr->parse('A+');    # I+ (augmented)
   $roman = $mtr->parse('BbM');   # bII (flat-two major)
+  $roman = $mtr->parse('Cm9/G'); # iii9/VII
 
   # Also:
   $mtr = Music::ToRoman->new(
@@ -147,9 +148,13 @@ version 0.0500
     scale_name => 'dorian',
     chords     => 0,
   );
-  $roman = $mtr->parse('A'); # i
-  $roman = $mtr->parse('B'); # ii
-  $roman = $mtr->parse('C'); # III
+  $roman = $mtr->parse('A');  # i
+  $roman = $mtr->parse('B');  # ii
+  $roman = $mtr->parse('C');  # III
+  $roman = $mtr->parse('D');  # IV
+  $roman = $mtr->parse('E7'); # v7
+  $roman = $mtr->parse('F#'); # vi
+  $roman = $mtr->parse('G');  # VII
 
 =head1 DESCRIPTION
 
@@ -183,12 +188,12 @@ Default: major
 
 =head2 chords
 
-Are we given chords with major ("M") and minor ("m") designations?
+Are we given chords to B<parse> with major ("M") and minor ("m") designations?
 
 Default: 1
 
-If this is set to 0, then only diatonic mode B<scale_name> output is rendered
-(other scales are ignored).
+If this is set to 0, single notes may be used to return the major/minor Roman
+numeral for the given diatonic mode B<scale_name>.
 
 =head1 METHODS
 
@@ -202,7 +207,17 @@ Create a new C<Music::ToRoman> object.
 
   $roman = $mtr->parse($chord);
 
-Parse a given chord name into a Roman numeral representation.
+Parse a note or chord name into a Roman numeral representation.
+
+For instance, the Roman numeral representation for the c<aeolian> (or minor)
+mode is: i ii III iv v VI VII - where the case indicates the major/minor status
+of the given chord.
+
+This can be overridden by parsing say, C<BM7> (B major seven), thus producing
+C<II7> in the key of A minor.
+
+If the B<chords> attribute is off and a single note is given, the diatonic mode
+of the B<scale_name> is used to find the correct Roman numeral representation.
 
 =head1 SEE ALSO
 
